# Providers
===================
[![PyPI version](https://badge.fury.io/py/provides.svg)](http://badge.fury.io/py/provides)

Providers is a simple library to enable function signature inheritance and dependency injection in a reusable and generic way.

